@@ -711,7 +711,7 @@ class OptionsManager(object):
         Resets (or initialises) self.options_dict to its default state.
         """
 
-        if os.name != 'nt':
+        if os.name == 'nt':
             windows_filenames_flag = True
         else:
             windows_filenames_flag = False
@@ -1384,9 +1384,17 @@ class OptionsParser(object):
         # Force youtube-dl's progress bar to be outputted as separate lines
         options_list = ['--newline']
 
-        # Create a copy of the dictionary...
+        # Create a copy of the dictionary
         copy_dict = options_manager_obj.options_dict.copy()
-        # ...then modify various values in the copy. Set the 'video_format' and
+
+        # Get the directory into which files are downloaded
+        dir_path = self.build_dir(
+            media_data_obj,
+            copy_dict,
+            operation_type,
+        )
+
+        # Modify various values in the copy. Set the 'video_format' and
         #   'all_formats' options
         self.build_video_format(media_data_obj, copy_dict, operation_type)
         # Set the 'min_filesize' and 'max_filesize' options
@@ -1465,6 +1473,16 @@ class OptionsParser(object):
                 else:
                     options_list.append(cookies_path)
 
+            elif option_holder_obj.name == 'trim_filenames':
+                length = copy_dict[option_holder_obj.name]
+                # The --trim-filenames option specifies a length that includes
+                #   the directory name. If the user has specified a length that
+                #   is shorter than the directory name, then ignore this
+                #   option
+                if length >= (len(dir_path) + 2):
+                    options_list.append('--trim-filenames')
+                    options_list.append(str(length))
+
             # For all other options, just check the value is valid
             elif option_holder_obj.check_requirements(copy_dict):
                 value = copy_dict[option_holder_obj.name]
@@ -1500,9 +1518,8 @@ class OptionsParser(object):
 
         # Parse the 'save_path_list' option
         options_list = self.build_paths(
-            media_data_obj,
+            dir_path,
             copy_dict,
-            operation_type,
             options_list,
         )
 
@@ -1645,13 +1662,11 @@ class OptionsParser(object):
                 copy_dict['proxy'] = proxy
 
 
-    def build_paths(self, media_data_obj, copy_dict, operation_type, \
-    options_list):
+    def build_dir(self, media_data_obj, copy_dict, operation_type):
 
         """Called by self.parse().
 
-        Build the value of the 'save_path_list' option, and add it directly to
-        the options list.
+        Finds the directory in which downloaded files are saved.
 
         Args:
 
@@ -1664,17 +1679,12 @@ class OptionsParser(object):
                 'classic_sim', 'classic_real', 'classic_custom' (matching
                 possible values of downloads.DownloadManager.operation_type)
 
-            options_list (list): List of download options compiled so far; this
-                function adds options directly to the list
-
         Return values:
 
-            The modified options_list
+            The output directory, as a string
 
         """
 
-        # First, set the download directory
-
         override_name = copy_dict['use_fixed_folder']
 
         if operation_type == 'classic_sim' \
@@ -1700,8 +1710,30 @@ class OptionsParser(object):
         else:
             dir_path = media_data_obj.get_actual_dir(self.app_obj)
 
-        # Secondly, set the file output template, which may be preceded by the
-        #   download directory
+        return dir_path
+
+
+    def build_paths(self, dir_path, copy_dict, options_list):
+
+        """Called by self.parse().
+
+        Build the value of the 'save_path_list' option, and add it directly to
+        the options list.
+
+        Args:
+
+            dir_path (str): The directory into which files are to be downloaded
+
+            copy_dict (dict): Copy of the original options dictionary
+
+            options_list (list): List of download options compiled so far; this
+                function adds options directly to the list
+
+        Return values:
+
+            The modified options_list
+
+        """
 
         # (When 'output_format_list' is specified, then 'output_format' and
         #   'output_template' are ignored. However, 'output_format_list' is
@@ -1782,26 +1814,8 @@ class OptionsParser(object):
                 #   'mp4_720p', 'convert_mp4_720p'
                 # Valid values are those specified by formats.VIDEO_FORMAT_LIST
                 #   formats.AUDIO_FORMAT_LIST and formats.VIDEO_RESOLUTION_LIST
-                format_str = media_data_obj.dummy_format
-                convert_flag = False
-                this_format = None
-                this_res = None
-
-                split_list = format_str.split('_')
-                if split_list and split_list[0] == 'convert':
-                    split_list.pop(0)
-                    convert_flag = True
-
-                if split_list \
-                and (
-                    split_list[0] in formats.VIDEO_FORMAT_LIST \
-                    or split_list[0] in formats.AUDIO_FORMAT_LIST
-                ):
-                    this_format = split_list.pop(0)
-
-                if split_list \
-                and split_list[0] in formats.VIDEO_RESOLUTION_LIST:
-                    this_res = formats.VIDEO_RESOLUTION_DICT[split_list.pop(0)]
+                convert_flag, this_format, this_res \
+                = utils.extract_dummy_format(media_data_obj.dummy_format)
 
                 if not convert_flag and this_res is None:
 
@@ -1867,25 +1881,13 @@ class OptionsParser(object):
                     copy_dict['video_format_mode'] = ''
                     copy_dict['recode_video'] = ''
 
-            # Special case: for broadcasting livestreams, use only HLS
-            # !!! DEBUG
-            # v2.0.067: Downloading livestreams doesn't work at all for me, so
-            #   I'm not sure whether this is appropriate, or not. Once it's
-            #   fixed, perhaps we can offer the user a choice of formats
-            if media_data_obj.live_mode:
-
-                copy_dict['video_format'] = '95'
-                copy_dict['all_formats'] = False
-                copy_dict['video_format_list'] = []
-                copy_dict['video_format_mode'] = ''
-
-                return
-
         # Special case: for simulated downloads, don't specify any video
         #   formats; if the format isn't available for some videos, we'll get
         #   an error for each of them (rather than the simulated download we
         #   were hoping for)
-        if operation_type == 'sim' or operation_type == 'classic_sim':
+        if operation_type == 'sim' \
+        or operation_type == 'classic_sim' \
+        or operation_type == 'custom_sim':
 
             copy_dict['video_format'] = '0'
             copy_dict['all_formats'] = False
